==> zenml_nightly-0.62.0.dev20240730.tar.gz: zenml_nightly-0.62.0.dev20240730/src/zenml/integrations/constants.py <==
#  Copyright (c) ZenML GmbH 2021. All Rights Reserved.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at:
#
#       https://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
#  or implied. See the License for the specific language governing
#  permissions and limitations under the License.
"""Constants for ZenML integrations."""

AIRFLOW = "airflow"
ARGILLA = "argilla"
AWS = "aws"
AZURE = "azure"
AZUREML = "azureml"
BENTOML = "bentoml"
BITBUCKET = "bitbucket"
COMET = "comet"
DASH = "dash"
DATABRICKS = "databricks"
DEEPCHECKS = "deepchecks"
DISCORD = "discord"
EVIDENTLY = "evidently"
FACETS = "facets"
FEAST = "feast"
GCP = "gcp"
GITHUB = "github"
GITLAB = "gitlab"
HUGGINGFACE = "huggingface"
HYPERAI = "hyperai"
GREAT_EXPECTATIONS = "great_expectations"
KANIKO = "kaniko"
KUBEFLOW = "kubeflow"
KUBERNETES = "kubernetes"
LABEL_STUDIO = "label_studio"
LANGCHAIN = "langchain"
LIGHTGBM = "lightgbm"
# LLAMA_INDEX = "llama_index"
MLFLOW = "mlflow"
NEPTUNE = "neptune"
NEURAL_PROPHET = "neural_prophet"
OPEN_AI = "openai"
PIGEON = "pigeon"
PILLOW = "pillow"
PLOTLY = "plotly"
POLARS = "polars"
PRODIGY = "prodigy"
PYCARET = "pycaret"
PYTORCH = "pytorch"
PYTORCH_L = "pytorch_lightning"
S3 = "s3"
SAGEMAKER = "sagemaker"
SCIPY = "scipy"
SELDON = "seldon"
SKLEARN = "sklearn"
SKYPILOT_AWS = "skypilot_aws"
SKYPILOT_GCP = "skypilot_gcp"
SKYPILOT_AZURE = "skypilot_azure"
SKYPILOT_LAMBDA = "skypilot_lambda"
SLACK = "slack"
SPARK = "spark"
TEKTON = "tekton"
TENSORBOARD = "tensorboard"
TENSORFLOW = "tensorflow"
VAULT = "vault"
WHYLOGS = "whylogs"
WANDB = "wandb"
VERTEX = "vertex"
XGBOOST = "xgboost"
VAULT = "vault"

==> zenml_nightly-0.84.2.dev20250813.tar.gz: zenml_nightly-0.84.2.dev20250813/src/zenml/integrations/constants.py <==
#  Copyright (c) ZenML GmbH 2021. All Rights Reserved.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at:
#
#       https://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
#  or implied. See the License for the specific language governing
#  permissions and limitations under the License.
"""Constants for ZenML integrations."""

AIRFLOW = "airflow"
ARGILLA = "argilla"
AWS = "aws"
AZURE = "azure"
AZUREML = "azureml"
BENTOML = "bentoml"
BITBUCKET = "bitbucket"
COMET = "comet"
DASH = "dash"
DATABRICKS = "databricks"
DEEPCHECKS = "deepchecks"
DISCORD = "discord"
EVIDENTLY = "evidently"
FACETS = "facets"
FEAST = "feast"
GCP = "gcp"
GITHUB = "github"
GITLAB = "gitlab"
HUGGINGFACE = "huggingface"
HYPERAI = "hyperai"
GREAT_EXPECTATIONS = "great_expectations"
KANIKO = "kaniko"
KUBEFLOW = "kubeflow"
KUBERNETES = "kubernetes"
LABEL_STUDIO = "label_studio"
LANGCHAIN = "langchain"
LIGHTGBM = "lightgbm"
# LLAMA_INDEX = "llama_index"
MLFLOW = "mlflow"
MODAL = "modal"
NEPTUNE = "neptune"
NEURAL_PROPHET = "neural_prophet"
NUMPY = "numpy"
OPEN_AI = "openai"
PANDAS = "pandas"
PIGEON = "pigeon"
PILLOW = "pillow"
PLOTLY = "plotly"
POLARS = "polars"
PRODIGY = "prodigy"
PYCARET = "pycaret"
PYTORCH = "pytorch"
PYTORCH_L = "pytorch_lightning"
S3 = "s3"
SAGEMAKER = "sagemaker"
SCIPY = "scipy"
SELDON = "seldon"
SKLEARN = "sklearn"
SKYPILOT_AWS = "skypilot_aws"
SKYPILOT_GCP = "skypilot_gcp"
SKYPILOT_AZURE = "skypilot_azure"
SKYPILOT_LAMBDA = "skypilot_lambda"
SKYPILOT_KUBERNETES = "skypilot_kubernetes"
SLACK = "slack"
SPARK = "spark"
TEKTON = "tekton"
TENSORBOARD = "tensorboard"
TENSORFLOW = "tensorflow"
VAULT = "vault"
WHYLOGS = "whylogs"
WANDB = "wandb"
VERTEX = "vertex"
XGBOOST = "xgboost"
VAULT = "vault"
VLLM = "vllm"
LIGHTNING = "lightning"
